package com.sample.common.util;

import java.util.Properties;

import javax.jms.JMSException;
import javax.jms.Queue;
import javax.jms.QueueConnection;
import javax.jms.QueueConnectionFactory;
import javax.jms.QueueSender;
import javax.jms.QueueSession;
import javax.jms.TextMessage;
import javax.naming.Context;
import javax.naming.InitialContext;

import org.apache.log4j.Logger;

public class JMSHelper
{
    private static Logger logger = Logger.getLogger("messaging_logger");

    public static void sendMessage(String _sText, String _sIpAddress)
    {
    	sendMessage(_sText, _sIpAddress, "jms/queue/AppsInboundQueue");
    }

    public static void sendMessage(String _sText, String _sIpAddress, String _sQueueName)
    {
    	QueueConnection qcon = null;
    	QueueSession qsession = null;
    	try
    	{
    		Properties jndiProps = new Properties();
    		jndiProps.put(Context.INITIAL_CONTEXT_FACTORY, "org.jboss.naming.remote.client.InitialContextFactory");
    		logger.info("provider ip: " + _sIpAddress);
    		jndiProps.put(Context.PROVIDER_URL,"remote://" + _sIpAddress + ":4447");

    		Context ctx = new InitialContext(jndiProps);

    		QueueConnectionFactory qcf = (QueueConnectionFactory)ctx.lookup("jms/RemoteConnectionFactory");
    		qcon = qcf.createQueueConnection();
    		qsession = qcon.createQueueSession(true, 0); //false, Session.AUTO_ACKNOWLEDGE);
    		logger.info("looking up " + _sQueueName);
    		Queue q = (Queue)ctx.lookup(_sQueueName);

    		QueueSender qsender = qsession.createSender(q);
    		qcon.start();

    		TextMessage message = qsession.createTextMessage();
    		message.setText(_sText);
    		qsender.send(message);
    		logger.info("message sent");

    		qsender.close();
    		qsession.close();
    		qcon.close();
    	}
    	catch (Exception e)
    	{
    		logger.error(e, e);
    	}
    	finally
    	{
    		try
    		{
    			if (qsession != null)
    			{
    				qsession.close();
    			}
    			if (qcon != null)
    			{
    				qcon.close();
    			}
    		}
    		catch (JMSException e)
    		{
    			logger.warn("Unable to close...", e);
    		}
    	}
    }

    /*
     * for store outbound mdb...:
	private static final String DEFAULT_CONNECTION_FACTORY = "ConnectionFactory1Mgmt";

//    		context = new InitialContext();
//    		connectionFactory = (ConnectionFactory)context.lookup(DEFAULT_CONNECTION_FACTORY);
//    		Connection connection = connectionFactory.createConnection();
//    		Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
//    		Queue queue = session.createQueue("AppsInboundQueue");
//    		MessageProducer producer = session.createProducer(queue);
//    		connection.start();
//    		TextMessage message = session.createTextMessage();
//    		message.setText(_sText);
//    		producer.send(message);
//    		session.close();
//    		connection.close();


     */


}
